#!/bin/bash

# createlinks.sh
# script de connexion utilisateur
# Prise en compte du wm utilisé avec les scripts createlinks_<wm>.sh
# Personnalisable avec createlinks_perso.sh
# 
# 20201002

ladate=$(date +%F+%T)
toto=$USER
tata=$USER
fichlog=/tmp/session-$USER.log

syncff="no" # passer à "yes" pour activer la synchro des profils ff (en test)

# Inscription de la date en tête du log
echo $ladate > $fichlog
echo "PAM_USER : $toto" >> $fichlog
echo "USER : $tata" >> $fichlog

# Répertoire de base des scripts, monté sur le client
clinuxdir=/mnt/clinux

#-------------------------------------------------------
# Détection du wm actif 
#-------------------------------------------------------
if [ "$GDMSESSION" = "lightdm-xsession" ]; then
WM="default"
elif [ "$GDMSESSION" = "LXDE" ]; then
WM="lxde"
elif [ "$GDMSESSION" = "mate" ]; then
WM="mate"
elif [ "$GDMSESSION" = "gnome" ]; then
WM="gnome"
elif [ "$GDMSESSION" = "cinnamon" -o "$GDMSESSION" = "cinnamon2d" ]; then
WM="cinnamon"
elif [ "$GDMSESSION" = "xfce" ]; then
WM="xfce"
elif [ "$GDMSESSION" = "plasma" ]; then
WM="kde"
fi

#----------------------
# Détection du DM actif
#----------------------
mondm=$(cat /etc/X11/default-display-manager | cut -d '/' -f4)

if [ "$mondm" = "gdm3" ]; then
DM="gdm3"
# Si gdm3 est actif, on l'associe à Gnome (pour l'instant)
WM="gnome"
elif [ "$mondm" = "lightdm" ]; then
DM="lightdm"
fi

echo "Environnement : $WM" >> $fichlog
echo "Gestionnaire de connexion : $DM" >> $fichlog

# Avant de continuer, utilisateur local ou AD ?
userloc=$(id -ng $toto)
echo $userloc >> $fichlog
if [ "$userloc" = "$toto" ];then
echo "$toto est un user local, on sort!" >> $fichlog
exit 0
else
echo "$toto est un user AD, on continue" >> $fichlog
fi

# Les commandes et scripts ci-dessous ne dépendent pas du wm :
# Applications par defaut
#touch /home/$toto/.config/mimeapps.list
cat /mnt/clinux/conex/mimeapps.list > /home/$toto/.config/mimeapps.list

# Masque les fichiers *.lnk, *.ini, *.exe du bureau 
# En mettant cette liste de fichiers dans le .hidden du bureau de l'utilisateur
#
echo "# On cache les raccourcis windoze..." >> $fichlog
pushd $(pwd)
cd /home/$USER/Bureau;
ls   *.lnk *.exe *.ini > /home/$USER/Bureau/.hidden
popd

# Lancement de createlinks_<wm>
echo "# Lancement de createlinks_$WM.sh" >> $fichlog
bash /mnt/clinux/conex/createlinks_$WM.sh

# Lancement de createlinks_perso
echo "# Lancement de createlinks_perso.sh" >> $fichlog
bash /mnt/clinux/conex/createlinks_perso.sh


# Lancement des autres scripts
#bash $clinuxdir/conex/alsavolume.sh
#bash $clinuxdir/conex/clean_vartmp.sh
#bash $clinuxdir/conex/warn_overfill.sh

echo "# Fin de l'exécution des scripts de connexion." >> $fichlog
exit 0
